# QWED Comprehensive Test Audit Report

**Generated:** 2025-12-01 09:55:24

**Duration:** 5.7 seconds

---

## Executive Summary

- **Total Tests:** 9
- **Passed:** 8 ✅
- **Failed:** 1 ❌
- **Pass Rate:** 88.9%

**Status:** ✅ GOOD

---

## Results by Priority

| Priority | Total | Passed | Failed | Pass Rate |
|----------|-------|--------|--------|-----------|
| ✅ CRITICAL | 3 | 3 | 0 | 100.0% |
| ⚠️ HIGH | 5 | 4 | 1 | 80.0% |
| ✅ MEDIUM | 1 | 1 | 0 | 100.0% |


## Results by Engine

| Engine | Total | Passed | Failed | Pass Rate |
|--------|-------|--------|--------|-----------|
| ✅ math | 9 | 8 | 1 | 88.9% |


## ❌ Failed Tests (1)

### Detect order of operations ambiguity
- **Engine:** math
- **Priority:** HIGH
- **Test ID:** `MATH_AMB_001`
- **Expected:** WARNING - Ambiguous (16 vs 1)
- **Timestamp:** 2025-12-01T09:55:18.591862

## ✅ Passed Tests (8)


### MATH Engine (8 tests)
- ✅ Handle implicit multiplication (2x vs 2*x) (3412ms)
- ✅ Detect division by zero (196ms)
- ✅ Detect sqrt of negative in real domain (204ms)
- ✅ Detect log(0) undefined (173ms)
- ✅ Verify true algebraic identity (411ms)
- ✅ Detect false algebraic identity (missing 2xy) (449ms)
- ✅ Detect sqrt(x²) ≠ x (should be |x|) (542ms)
- ✅ Verify simple arithmetic (2+2=4) (191ms)

---

*Generated by QWED Advanced Testing Framework*
